import { FrameState, FrameStateAPI, UseFrameStateOptions } from './unstable-types.cjs';
import 'frames.js';
import 'frames.js/frame-parsers';
import 'react';
import 'frames.js/types';
import './types-UBxj8iVV.cjs';

type ExtraPending = {
    startTime: Date;
    requestDetails: {
        body?: object;
        searchParams?: URLSearchParams;
    };
};
type SharedResponseExtra = {
    response: Response;
    responseStatus: number;
    responseBody: unknown;
    /**
     * The speed of the response in seconds
     */
    speed: number;
};
type ExtraDone = SharedResponseExtra;
type ExtraDoneRedirect = SharedResponseExtra;
type ExtraRequestError = Pick<SharedResponseExtra, "speed"> & {
    response: Response | null;
    responseStatus: number;
    responseBody: unknown;
};
type ExtraMessage = SharedResponseExtra;
type DebuggerFrameState = FrameState<ExtraPending, ExtraDone, ExtraDoneRedirect, ExtraRequestError, ExtraMessage>;
type DebuggerFrameStateAPI = FrameStateAPI<ExtraPending, ExtraDone, ExtraDoneRedirect, ExtraRequestError, ExtraMessage>;
type DebuggerFrameStateOptions = Omit<UseFrameStateOptions<ExtraPending, ExtraDone, ExtraDoneRedirect, ExtraRequestError, ExtraMessage>, "resolveDoneExtra">;
declare function useDebuggerFrameState(options: DebuggerFrameStateOptions): [DebuggerFrameState, DebuggerFrameStateAPI];

export { useDebuggerFrameState };
